#!/usr/bin/env python
# -*- coding: utf-8 -*-
# _version.py
"""Package initialization for IQDM-PDF."""
# Copyright (c) 2021 Dan Cutright
# This file is part of IQDM-PDF, released under a MIT license.
#    See the file LICENSE included with this distribution

__author__ = "Dan Cutright"
__version__ = "0.2.4.post1"
__release__ = "0.2.4.post1"
